<?php

namespace FiloBlu\ExtInventory\Model;

use Magento\Framework\App\ResourceConnection;
use Zend_Db;

/**
 * Class Reservation
 * @package FiloBlu\ExtInventory\Model
 */
class Reservation implements ReservationInterface
{
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;

    /**
     * Reservation constructor.
     * @param ResourceConnection $resourceConnection
     */
    public function __construct(ResourceConnection $resourceConnection)
    {
        $this->resourceConnection = $resourceConnection;
    }

    /**
     * @inheritDoc
     */
    public function getReservationQuantity($sku, $sourceCode, $allowedOrderStatuses = [])
    {
        $filoBluOrderItem = $this->resourceConnection->getTableName('inventory_fb_orderitem_source');
        $salesOrder = $this->resourceConnection->getTableName('sales_order');
        $connection = $this->resourceConnection->getConnection();

        $reservedQuantity = $connection->fetchRow("SELECT SUM(ifos.qty) AS `qty` FROM `{$filoBluOrderItem}` AS `ifos` INNER JOIN `{$salesOrder}` so ON ifos.order_id = so.entity_id
    WHERE `sku` = :sku AND `inventory_source_id` = :source AND so.status IN (:order_status)
    GROUP BY `sku`", ['sku' => $sku, 'source' => $sourceCode, 'order_status' => $allowedOrderStatuses], Zend_Db::FETCH_ASSOC);

        if ($reservedQuantity) {
            return (float)$reservedQuantity['qty'];
        }

        return 0.0;
    }
}
